@@ -62,7 +62,7 @@ require Exporter;
 @EXPORT_OK = qw(marc_map);
 %EXPORT_TAGS = (all => [qw(marc_map)]);
 
-our $VERSION = '0.217';
+our $VERSION = '0.218';
 
 sub marc_map {
     my ($data,$marc_path,%opts) = @_;
@@ -162,7 +162,12 @@ sub marc_map {
     			}
         	}
         }
-    	push (@vals,$v) if ( (ref $v eq 'ARRAY' && @$v) || (ref $v eq '' && length $v ));
+        if (ref $v eq 'ARRAY' && @$v) {
+            push (@vals,@$v);
+        }
+        elsif (ref $v eq '' && length $v ) {
+            push (@vals,$v);
+        }
     }
 
     if (wantarray) {
